
#include <unistd.h>
#include <stdio.h>
#include <stdlib.h>
#include <signal.h>
#include <errno.h>
#include <sys/ioctl.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <assert.h>

#include "daq.h"

int irq_table[]  = {3, 4, 5, 7, 10, 11, 12, 15};
int irq_lookup[] = {-1, -1, -1, 0, 1, 2, -1, 3, -1, -1, 4, 5, 6, -1, -1, 7};
    int			fd;


int get_irq(int fd) {
    int				err;
    struct device_statistics	ds;

    if((ioctl(fd, _IOR('N',5,ds), &ds)) == -1)
	{err=errno; perror("ioctl(fd, NIOC_READSTATS, ds)"); exit(err);}
    return ds.irq;
}

void get_stats(int sig_num) {
    int				err;
    struct device_statistics	ds;

    if((ioctl(fd, _IOR('N',5,ds), &ds)) == -1)
	{err=errno; perror("ioctl(fd, NIOC_READSTATS, ds)"); exit(err);}

    printf("\nspurious_irqs=%u, erroneous_irqs=%u, valid_irqs=%u, timeouts=%u measurements=%u\n",
	   ds.spurious_irqs, ds.erroneous_irqs, ds.valid_irqs, ds.timeouts, ds.measurements);
}

int main(int argc, char *argv[])
{
    int			err, i;
    unsigned		data;
    double		f;

    if((fd=open("daq", O_RDWR)) == -1)
	{err=errno; perror("open(daq, O_RDWR)"); exit(err);}

    signal(SIGINT, get_stats);

    i = 1;
    do {
	if(read(fd, &data, sizeof(data)) != sizeof(data))
	    {err=errno; perror("read");}
	printf("Reading %d, 0x%.4x (%.4f)\r", i, data, f=data/6553.6);
	i++;
    } while (f<1.6 && f>1.3);

    if(close(fd))
	{err=errno; perror("close"); exit(err);}

    return 0;
}
